WebViewCookie class

A cookie that can be set globally for all web views using WebViewCookieManagerPlatform.

Constructors

WebViewCookie({required String name, required String value, required String domain, String path = '/'})
Constructs a new WebViewCookie.
const

Properties

domain → String
The domain-value of the cookie.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The cookie-name of the cookie.
final
path → String
The path-value of the cookie. Is set to / in the constructor by default.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
The cookie-value of the cookie.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, String>
Serializes the WebViewCookie to a Map<String, String>.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited